# HILmux Python-Examples

This contains a small library to easily communicate with HILmux devices. It can do everything except for performing firmware updates.

## Dependencies

The only current dependency is `pyserial` (specified in `requirements.txt`).

Install it using either `pip install pyserial`, or better `pip install -r requirements.txt`.

It is expected that a somewhat recent version of Python 3 is used (as of writing this, at least **Python 3.8**)!

### Distribution

These examples are not allowed to be freely re-distributed beyond your own company. Only ITB-Solutions GmbH holds this right.

However, if we provided these files to you, you are fee to modify and use these files in any way you need.

## Library overview

The library consists out of these files:
 - `hilmux.py`: Main file that allows to find and communicate with HILmux devices easily
 - `hilmux_proto.py`: Contains the datatypes used in communcation as well as encoding/decoding of these
 - `test_proto.py`: Small unittest that does some basic check to ensure the protocol is implemented sane and rule out most runtime errors.

For more information, refer to the docstrings in these files. If anything is unclear, please contact us at Info@ITB-Solutions.de or via an existing contact.

## Examples

These examples were implemented on request and demonstrate how to use this library/talk with the HILmux:

### `create_config_file.py`

This uses `hilmux.discover()` to open all eligable ports and wait for a potential `StatusAliveFactorySetting` status.

All found devices will have a configuration created that looks like this:

`HILmux_01020000.cfg`:

```ini
[HILmux]
serialnumber = 01020000
last_known_device = /dev/ttyUSB0
uc1_display_name = uC 1
uc2_display_name = uC 2
```

This can be used in later examples.

### `set_HILmux.py`

This example can consume the created config (specify it via `-c/--config <FILE>`).
If the config is specified, it will first try the `last_known_device` and send a request for `StatusAliveFactorySetting` to it.
If this does not get received, or some other issue happens (port non-existant, failed to parse Status) it will try to search for the device matching the `serialnumber` on all eligable ports and update the value of `last_known_device` unless `-U/--no-config-update` was specified.

If the last_used_port is correct, using a config is faster than doing a search, since there is no need to passively wait for `StatusAliveFactorySetting`.

Alternatively you can also specify `-s/--serialnumber <SERIAL>` and/or `-d/--device <DEVICE>` to find a device.

If nothing is specified, the program will still try to find any HILmux. However, it will fail it finds none or more than one HILmux!

You can then change the state of uC 1/2 using `-1/--uc1 <Disconnected/Xetk/Lauterbach>` and/or `-2/--uc2 <Disconnected/Xetk/Lauterbach>`.

Using `--help` will give you an overview over these cli parameter as well. 

### `Start_GUI`

This starts a tkinter-based GUI. It will allow you to change the state of the uCs and Lock/Unlock the device.

The state represents only what the device reports, so it can also be used to just display that.

Except for `-1/--uc1` and `-2/--uc2` all the parameters and behavior for finding a HILmux are inherited from `set_HILmux.py`. Therefore this **depends on set_HILmux.py being present** as well!

When using a configuration file, the display names for uC1 and uC 2 will be shown, if you changed them.
