#!/usr/bin/env python3
"""
Example script that scans for all HILmux devices and creates a config for each.
"""

import hilmux

from configparser import ConfigParser
from sys import stderr

def main():
    found = 0
    # Without any specification (device or serialnumber), discover() will find all devices
    for discovered_device in hilmux.discover(None, None):
        print(f"{discovered_device.device}: HILmux-{discovered_device.serialnumber}")        
        found += 1

        # Write config
        config = ConfigParser()
        config["HILmux"] = {
            "serialnumber": discovered_device.serialnumber,
            "last_known_device": discovered_device.device,
            "uc1_display_name": "uC 1",
            "uc2_display_name": "uC 2",
        }
        with open(f"HILmux_{discovered_device.serialnumber}.cfg", "w") as configfile:
            config.write(configfile)

    if found == 0:
        print("Failed to detect any HILmux!", file=stderr)
        exit(1)

if __name__ == "__main__":
    main()